%
% Miguel A. Carreira-Perpinan's MACPcv.cls file.
% Time-stamp: <16/06/25 19:47:58 mcarreira-perpinan>
% See version number in line "ProvidesClass" below.
%

% (C) 1998-2016 Miguel A. Carreira-Perpinan
%     Electrical Engineering and Computer Science
%     University of California, Merced
%     http://eecs.ucmerced.edu
%
%
% DOCUMENTATION
%
% This is my personal LaTeX2e class for typesetting CVs. To use it, read
% the following instructions and look at the example files cv*.tex provided .
%
% MACPcv.cls accepts the following options from the standard article class:
% twocolumn/onecolumn, 10pt/11pt/12pt, twoside, a4paper/letterpaper
% (no other paper types are considered) and some other irrelevant options
% (draft, fleqn, leqno, openbib).
%
% Plus the following extra options:
%
% - "titleft": section titles appear on the left margin instead of on the
%   top of the section body. Use \\ if necessary to split the section
%   title into lines adequately.
% - "tittop": section titles appear on the top of the section body.
% 
% - "PofP": page numbers appear as 2/3 rather than 2.
% - "noPofP": page numbers appear as 2.
%
% - "nohyperref": to disable use of hyperref (links, bookmarks, etc.).
%   By default, hyperref is enabled.
%
% It does not use the following options from the standard article class:
% a5paper/b5paper/legalpaper/executivepaper, landscape, titlepage.
%
% The default options are: 10pt,tittop,noPofP,letterpaper,onecolumn.
%
% The basic features are:
%
% - Use the \name and \address commands in the preamble to give the name
%   and address of the person. The only purpose of this address is to be
%   printed on the top of the first page of the CV, so it should be less
%   than one line long.
%   If no \address is given, the name is centred in the top of the first
%   page above a rule. Otherwise, the name is left-justified above the
%   rule and the address right-justified below the rule.
% 
% - Enclose the CV text in a "cv" environment. This will produce the
%   title (name + address) in the first page and the date in the last one,
%   and typeset nicely the sections, etc.
% 
% - Use the \section command and the list environments below to structure
%   the CV. Don't use the standard "itemize", "enumerate" or "description"
%   environments at the beginning of a section because the spacing will be
%   wrong. The \section command and the paragraph indentation have been
%   redefined to look nicer.
% 
% - Two new list environments ("datelist", "Simplelist") have been added:
% 
%   . The "datelist" environment is useful to list items associated to
%     dates, e.g. a list of degrees or of past positions. Every date is
%     given as an item label and set flushed left in boldface, with the
%     rest of the text indented; the separation between items is large
%     to identify clearly each item (which in turn may contain other
%     lists).
%     One can use a simple sequence of paragraphs instead but has to
%     provide with boldface and extra space between items if necessary.
%     Syntax: like the standard "description" environment.
% 
%   . The "Simplelist" environment is useful to list a number of things
%     without special formatting. No boldface is provided, a triangle
%     is used as default bullet (but can be changed either globally as
%     an argument or individually for each item as in the standard
%     "itemize"), the items are flushed left, the text is not indented and
%     the separation between items is small.
%     Syntax: like the standard "itemize" environment plus optional bullet.
% 
% - There is also an "ncolumn" environment which is useful to list short
%   items both rowwise and linewise. A triangle is used as default bullet
%   (but a custom one may be given as an optional argument).
%   Syntax:
% 
%   \begin{ncolumn}[\textbullet]{3}
%   column 1 & column 2 & column 3 \\
%   column 1 & column 2 & column 3 \\
%   ...
%   \end{ncolumn}
% 
%   where the [\textbullet] argument is optional and gives the bullet
%   to be used for every entry, and {3} is the number of columns.
%   Separate columns by & and lines by \\.
% 
% - Use the "personal" environment to give your personal data. Don't use
%   a "tabbing" or "tabular" environment for this because the spacing
%   will be wrong.
%   Syntax:
% 
%   \begin{personal}
%   filed_name & field_value \\
%   ...
%   \end{personal}
% 
% - Use the "publications" environment to list your publications or grants,
%   separating different ones by simple blank lines.
% 
% - Use the "references" environment to include the name and addresses of
%   referees, separating different references with an \and command and
%   using \\ as necessary.
%
% There are lots of things that are fixed in the class but can easily be
% modified by editing the class file, e.g. the font family or size of the
% title, section names and headings; the location of the date (last page,
% flushed right); etc. I have not bothered to make the style more
% flexible since I don't need to.
%
%
% NOTES
%
% If using hyperref, run pdflatex (not latex+dvips) so that hyperref works
% well with links broken across an end-of-line. With hyperref, bookmarks
% are generated for the sections (publications, grants, etc.), and you can
% use commands such as \href or \url to create links. See the instructions
% for the hyperref package.
%
% Use formatting commands as need to improve the visual appearance:
% \newpage, \enlargethispage*{1cm}, etc.
%
% For the "titleft" and "twocolumn" options it may be necessary to use 10pt
% and some compact font (such as Times) to avoid over/underfulls, e.g.:
%
% \documentclass[10pt,a4paper,twocolumn]{MACPcv}
% \usepackage{times}
%
%
% FONTS
%
% Nice combinations can be obtained by using other fonts than the
% standard Computer Modern. For example, putting this in the preamble
% would use the Adobe Times Roman (ptm), Adobe Helvetica (phv) and
% Computer Modern Typewriter (cmtt) fonts for the three font families
% indicated:
% 
% \renewcommand{\rmdefault}{ptm}          % Roman family     
% \renewcommand{\sfdefault}{phv}          % Sans serif family
% \renewcommand{\ttdefault}{cmtt}         % Typewriter family
%
% The psnfss2e.tex file lists a number of fonts.
%
%
% BUGS
%
% For the "titleft" option:
%
% - The alignment of the section title and the section body is poor.
% 
% - The title of a section can appear at the bottom of a page and the
%   first line of its body section at the top of the following page.
%   Perhaps this is due to the poor alignment of the previous point.
% 
% - If the body of a section is split across more than one page, should
%   the section title appear in every page?
% 
% - If the section title is longer (in number of lines) than the body,
%   the section title will overlap with the following section.
%
% For the "twocolumn" option:
%
% - The title spacing is very crappy.
%
% For all options:
%
% - The geometry package must be loaded inside MACPcv.cls before the
%   definition of \origtextwidth. Otherwise, the horizontal rules
%   for the page header and section titles get the wrong width.
%
%
% TO DO (PERHAPS)
%
% Add the place together with the date in the last page? E.g. "Sheffield,
% April 30, 1998"?
%
% Append \dotfill\ or \hrulefill\ to the label in the "datelist" environment.
% Currently, I need to put them explicitly in the cv file after any label.
%
% Be able to use an external .bib file to keep the publications.
%
% Add a vertical rule separating the area for the section titles (to the
% left) and the text body (to the right).
%
%
% CREDITS
%
% Inspired by Kim Border's (kcb@hss.caltech.edu) hssvita.cls and Michael
% DeCorte's (mrd@sun.soe.clarkson.edu) res.sty.
%
%        
%%% ====================================================================

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{MACPcv}[2016/06/25 v3.0 Miguel A. Carreira-Perpinan's CV style]
\RequirePackage{ifthen}[1994/06/01]

%-----------------------------------------------------------------------
%
% Options
%

% Location of section titles: left margin ("titleft") or on top (default)
\newboolean{titleft}
\DeclareOption{titleft}{\setboolean{titleft}{true}}
\DeclareOption{tittop}{\setboolean{titleft}{false}}

% Page number display: "2/3" or "2" (default)
\newboolean{PofP}
\DeclareOption{PofP}{\setboolean{PofP}{true}}
\DeclareOption{noPofP}{\setboolean{PofP}{false}}

% Point size of the main text: 10pt, 11pt or 12pt
\newboolean{tenpt}
\DeclareOption{10pt}{\setboolean{tenpt}{true}%
\PassOptionsToClass{\CurrentOption}{article}}
\newboolean{elvpt}
\DeclareOption{11pt}{\setboolean{elvpt}{true}%
\PassOptionsToClass{\CurrentOption}{article}}
\newboolean{tlvpt}
\DeclareOption{12pt}{\setboolean{tlvpt}{true}%
\PassOptionsToClass{\CurrentOption}{article}}

% Paper type: either A4 (European) or letter (American)
\newboolean{@4paper}
\DeclareOption{letterpaper}{\setboolean{@4paper}{false}%
\PassOptionsToClass{\CurrentOption}{article}}
\DeclareOption{a4paper}{\setboolean{@4paper}{true}%
\PassOptionsToClass{\CurrentOption}{article}}

% Text body: either in one or two columns
\newboolean{twocol}
\DeclareOption{onecolumn}{\setboolean{twocol}{false}}
\DeclareOption{twocolumn}{\setboolean{twocol}{true}%
\setboolean{titleft}{false}%
\PassOptionsToClass{\CurrentOption}{article}}

% Pass some options to the standard article class
\DeclareOption{twoside}{\PassOptionsToClass{\CurrentOption}{article}}
\DeclareOption{draft}{\PassOptionsToClass{\CurrentOption}{article}}
\DeclareOption{fleqn}{\PassOptionsToClass{\CurrentOption}{article}}
\DeclareOption{leqno}{\PassOptionsToClass{\CurrentOption}{article}}
\DeclareOption{openbib}{\PassOptionsToClass{\CurrentOption}{article}}

% Switch off some of the article options
\DeclareOption{a5paper}{\OptionNotUsed}
\DeclareOption{b5paper}{\OptionNotUsed}
\DeclareOption{legalpaper}{\OptionNotUsed}
\DeclareOption{executivepaper}{\OptionNotUsed}
\DeclareOption{landscape}{\OptionNotUsed}
\DeclareOption{titlepage}{\OptionNotUsed}

% Don't use hyperref (and bookmark)
\newboolean{nohyperref}
\setboolean{nohyperref}{false}% by default, use hyperref
\DeclareOption{nohyperref}{\setboolean{nohyperref}{true}}

\DeclareOption*{\ClassWarning{MACPcv}{`\CurrentOption' option ignored}}

\ExecuteOptions{10pt,tittop,noPofP,letterpaper,onecolumn}% Default options
\ProcessOptions\relax

% Based in the standard article class
\LoadClass{article}

%-----------------------------------------------------------------------
%
% Font for the section titles: \sectfont.
%
\ifthenelse{\boolean{titleft}}%
{\newcommand{\sectfont}{\scshape}}% "titleft" option
{\newcommand{\sectfont}{\large\scshape}}% standard

%-----------------------------------------------------------------------
%
% Text dimensions for European paper
%
%\ifthenelse{\boolean{@4paper}}{%
%\setlength{\topmargin}{-1.5cm}%
%\setlength{\textheight}{25cm}%
%\setlength{\textwidth}{16.5cm}%
%\setlength{\oddsidemargin}{-0.5cm}%
%\setlength{\evensidemargin}{-0.5cm}%
%}{%
%\setlength{\topmargin}{-1.5cm}%
%\setlength{\textheight}{24cm}%
%\setlength{\textwidth}{17.3cm}%
%\setlength{\oddsidemargin}{-0.5cm}%
%\setlength{\evensidemargin}{-0.5cm}%
%}
\RequirePackage[margin=0.7in]{geometry}

%-----------------------------------------------------------------------
%
% Left margin offset to make room for the section titles in "titleft" option:
%   \marginoffset.
%
\newlength{\marginoffset}
\ifthenelse{\boolean{titleft}}{% "titleft" option needs extra margin on the left
% Set \marginparwidth to a convenient size so that the section titles
% are typeset nicely, e.g. avoiding word breaks.
\settowidth{\marginparwidth}{\sectfont Professional}
\setlength{\marginoffset}{\marginparwidth}
\addtolength{\marginoffset}{\marginparsep}
}{% Otherwise no extra margin is necessary
\setlength{\marginoffset}{0cm}
}

%-----------------------------------------------------------------------
%
% Original text width for use in rules and several kinds of headers:
%   \origtextwidth.
%
\newlength{\origtextwidth}
\setlength{\origtextwidth}{\textwidth}

%-----------------------------------------------------------------------
%
% Text width in normal paragraph mode: \newtextwidth.
%
\newlength{\newtextwidth}
\setlength{\newtextwidth}{\textwidth}
\ifthenelse{\boolean{twocol}}{% "twocolumn"
\setlength{\columnsep}{12pt}
\setlength{\columnseprule}{0pt}
% For some reason \columnwidth is shorter than the actual width of the
% column, so I compute it myself.
\addtolength{\newtextwidth}{-\columnsep}%
\setlength{\newtextwidth}{.5\newtextwidth}%
}{%
\ifthenelse{\boolean{titleft}}{% "titleft"
\addtolength{\newtextwidth}{-\marginoffset}%
}{%
}% "onecolumn"
}

%-----------------------------------------------------------------------
%
% Correction of the text width and page margins.
%
\addtolength{\oddsidemargin}{\marginoffset}
\addtolength{\evensidemargin}{\marginoffset}
\addtolength{\textwidth}{-\marginoffset}

%-----------------------------------------------------------------------
%
% Rules: \decorativerule for page headings, \simplerule for section headers.
% Adapted from hssvita.cls.
%
\newcommand{\decorativerule}{%
\mbox{\protect\rule[0.03in]{\origtextwidth}{0.02in}}%
\hspace*{-\origtextwidth}%
\mbox{\protect\rule[0in]{\origtextwidth}{0.01in}}%
}

\ifthenelse{\boolean{twocol}}{%
\newcommand{\simplerule}{%
\mbox{\protect\rule[0in]{\newtextwidth}{0.01in}}%
}}%
{%
\newcommand{\simplerule}{%
\mbox{\protect\rule[0in]{\origtextwidth}{0.01in}}%
}}

%-----------------------------------------------------------------------
%
% Paragraph formatting
%
\setlength{\parindent}{0pt}             % No indentation but...
\setlength{\parskip}{.5\baselineskip}   % larger separation between paragraphs

\frenchspacing                          % To avoid large space after period

%-----------------------------------------------------------------------
%
% List environments: all of them ensure that there is no extra space above
% or below the list environment, so that it can be properly aligned.

%
% "datelist": useful for listing positions/degrees held.
%
\newenvironment{datelist}%
{%
\begin{list}{}{
\vspace{-\topsep}
\vspace{-\partopsep}
\setlength{\itemindent}{0cm}
\setlength{\leftmargin}{0.5cm}
\setlength{\rightmargin}{0cm}
\setlength{\listparindent}{0cm}
\setlength{\labelwidth}{\leftmargin}
\addtolength{\labelwidth}{-\labelsep}
\setlength{\itemsep}{0ex}
\renewcommand{\makelabel}[1]{\bfseries ##1:}
}%
}%
{%
\end{list}
\vspace{-\topsep}
\vspace{-\partopsep}
}

%
% "Simplelist": useful for compact lists. Use it instead of "itemize".
% Optional argument: the bullet (default \triangleright). Other nice
% bullets are available in the Zapf Dingbats font (e.g. \ding{166} in
% the pifont package).
%
\newenvironment{Simplelist}[1][$\triangleright$]%
{%
\begin{list}{#1}{
\vspace{-\topsep}
\vspace{-\partopsep}
\setlength{\itemindent}{0cm}
\setlength{\rightmargin}{0cm}
\setlength{\listparindent}{0cm}
\settowidth{\labelwidth}{#1}
\setlength{\leftmargin}{\labelwidth}
\addtolength{\leftmargin}{\labelsep}
\setlength{\itemsep}{0cm}
%\setlength{\leftmargin}{0cm}
%\setlength{\labelwidth}{0cm}
}%
}%
{%
\end{list}
\vspace{-\topsep}
\vspace{-\partopsep}
}

%-----------------------------------------------------------------------
%
% "ncolumn" environment: useful to list a few small items in a nice way.
% Adapted from res.sty.
%
\newlength{\@columnspacing}     % Minimum spacing between columns
\setlength{\@columnspacing}{0.5cm}

\newlength{\@columnwidth}       % Temporal variables to compute the
\newlength{\@columnwidthtmp}    % width of each column

\newenvironment{ncolumn}[2][$\triangleright$]{% Default bullet: \triangleright
\setlength{\@columnwidthtmp}{\newtextwidth}
\addtolength{\@columnwidthtmp}{\@columnspacing}
\@columnwidth=\@columnwidthtmp \divide\@columnwidth by #2     % TeX calculation
\settowidth{\@columnwidthtmp}{\hspace*{\@columnspacing}#1~}
\addtolength{\@columnwidth}{-\@columnwidthtmp}% Width of each column
\ifthenelse{\boolean{titleft}}{\vspace{-\mystery}}{}%
\begin{tabular}[t]{@{\hspace*{-\@columnspacing}}*{#2}{@{\hspace*{\@columnspacing}#1~}p{\@columnwidth}@{\extracolsep{\fill}}}}%
}%
{\end{tabular}\par}

%-----------------------------------------------------------------------
%
% Page headings
% Adapted from hssvita.cls.
%
\pagenumbering{arabic}
\pagestyle{headings}

\renewcommand{\@oddhead}{%
\hspace*{-\marginoffset}%
\begin{minipage}{\origtextwidth}%
  \ifthenelse{\boolean{PofP}}%
  {\makebox[\origtextwidth]{\normalfont\small\@name\hfill\thepage/\pageref{lastpage}}}% Page numbers as "2/3"
  {\makebox[\origtextwidth]{\normalfont\small\@name\hfill\thepage}}% Page numbers as "2"
  \\[-0.2cm]%
  \decorativerule%
\end{minipage}}%

\renewcommand{\@evenhead}{% Only useful for "twoside" option
  \begin{minipage}{\origtextwidth}%
    \ifthenelse{\boolean{PofP}}%
    {\makebox[\origtextwidth]{\normalfont\small\thepage/\pageref{lastpage}\hfill\@name}}% Page numbers as "2/3"
    {\makebox[\origtextwidth]{\normalfont\small\thepage\hfill\@name}}% Page numbers as "2"
    \\[-0.2cm]%
    \decorativerule%
\end{minipage}}%

%-----------------------------------------------------------------------
%
% Commands to store the name and address of the CV's author
% Adapted from hssvita.cls and res.sty.
%
\newcommand{\@name}{}
\newcommand{\name}[1]{\renewcommand{\@name}{#1}}

\newcommand{\@address}{}
\newboolean{@ddr}
\setboolean{@ddr}{false}
\newcommand{\address}[1]{\renewcommand{\@address}{#1}\setboolean{@ddr}{true}}

%-----------------------------------------------------------------------
%
% Redefine \section command
%
% For some reason:
% - A one-line section title gets wrong spacing, so I need to add a
%   "phantom" line to it.
% - The alignment between the first line of the section title and the
%   first line of the section body is not quite right, and varies
%   mysteriously with the point size of the main text font and with the
%   kind of environment with which the section starts.
% - A section body may appear at the top of a page while its section
%   title is at the bottom of the previous page, perhaps due to the
%   poor alignment mentioned in the previous point.
%
% Note that the space above and below the \section goes in the \section
% command itself, not in the text or environments in the body.
%
% These lengths are necessary for alignment ("titleft" option)
\newlength{\mystery}
\ifthenelse{\boolean{tenpt}}{\setlength{\mystery}{1pt}}% 10pt
{\ifthenelse{\boolean{elvpt}}{\setlength{\mystery}{2pt}}% 11pt
{\setlength{\mystery}{2.5pt}}}% 12pt
%
\newlength{\mysteryheight}
\settoheight{\mysteryheight}{A}
\addtolength{\mysteryheight}{6pt}
\addtolength{\mysteryheight}{\mystery}
%
\newlength{\secttitledepth}
\newsavebox{\secttitle}

% No section numbers
\setcounter{secnumdepth}{0}
 
\ifthenelse{\boolean{titleft}}%
{% If "titleft" option is selected, section titles go in the margin:
\renewcommand{\section}[1]{%
\bigskip\pagebreak[2]% Encourage page break just before a new section
\savebox{\secttitle}{\begin{minipage}[t]{\marginparwidth}\raggedleft\sectfont #1\\ \phantom{.}\end{minipage}}
\settodepth{\secttitledepth}{\usebox{\secttitle}}%
\hspace*{-\marginoffset}%
\usebox{\secttitle}%
\vspace{-\secttitledepth}\vspace{-\mysteryheight}%
\ifthenelse{\boolean{nohyperref}}{}{\pdfbookmark[0]{#1}{#1}}% for hyperref
{\nopagebreak\par}}%
}{%
% Otherwise, section titles go in the text body:
\renewcommand{\section}[1]{%
\bigskip\pagebreak[2]% Encourage page break just before a new section
\begin{minipage}{\newtextwidth}%
{\sectfont #1}\\[-.85\baselineskip]%
\simplerule%
\end{minipage}%
\ifthenelse{\boolean{nohyperref}}{}{\pdfbookmark[0]{#1}{#1}}% for hyperref
{\nopagebreak\par}}%
}%

%-----------------------------------------------------------------------
%
% "cv" environment: creates a suitable title and puts the date at the end.
% Adapted from hssvita.cls.
%
% The title for the "twocolumn" option is really crappy, but I don't know
% how to bring down BOTH columns a distance ONLY in the first page. Also,
% I don't know how to prevent LaTeX from complaining that it overflows.
%
\newenvironment{cv}{%
% --- Opening: name + rule + address at the top of the first page
\thispagestyle{empty}%
\vspace*{-\headsep}\vspace*{-\headheight}% Remove separation due to headers
\ifthenelse{\boolean{twocol}}{\vspace*{-0.5cm}\setlength{\topskip}{0.8cm}}{}%
\hspace*{-\marginoffset}\begin{minipage}{\origtextwidth}%
%
\ifthenelse{\boolean{@ddr}}% Name. If \address was given...
{{\Large\bfseries\@name}\\[-0.1cm]}% ...Flush left the \name
{\centerline{\Large\bfseries\@name}}% ...Otherwise centre it
%
\decorativerule\\[-0.1cm]% Rule
%
\makebox[\origtextwidth]{\hfill\@address}% Address
\end{minipage}}%
% --- Closing: date at the bottom of the last page
{%
  \ifthenelse{\boolean{PofP}}%
  {\par\samepage\vfill\hfill\label{lastpage}\today}% Page numbers as "2/3"
  {\par\samepage\vfill\hfill\today}%                 Page numbers as "2"
}

%-----------------------------------------------------------------------
%
% "publications" environment: different publications are kept in different
% paragraphs, highlighted with hanging indentation.
%
\newlength{\entryhang}
\setlength{\entryhang}{0.5cm}
\newenvironment{publications}[1][Publications list]{%
\section{#1}%
% I don't know how to get hanging indentation in LaTeX, so I use TeX commands
\@setpar{\hangindent\entryhang \hangafter=1\@@par}%
% Slightly larger separation to highlight paragraphs
\setlength{\parskip}{.5\baselineskip}%
}{\par}

%-----------------------------------------------------------------------
%
% "references" environment: fits a maximum of 2 side-by-side references
% (onecolumn format) or 1 reference per line (twocolumn format).
% Adapted from hssvita.cls.
%
\newlength{\referencewidth}     % Default width of reference entries
\ifthenelse{\boolean{twocol}}{%
\setlength{\referencewidth}{\newtextwidth}%
\newcommand{\refsep}{\par}%
}{%
\setlength{\referencewidth}{.45\textwidth}%
\newcommand{\refsep}{\hfill\vspace{\baselineskip}}%
}
%
\newenvironment{references}{%
\section{References}%
\setlength{\parskip}{\baselineskip}%
\vspace{-.5\baselineskip}\begin{minipage}[t]{\referencewidth}\flushleft}%
{\end{minipage}\par}
%
\renewcommand{\and}{%
\end{minipage}\refsep%
\begin{minipage}[t]{\referencewidth}\flushleft}

%-----------------------------------------------------------------------
%
% "personal" environment: useful to line up personal data in two columns.
%
\newenvironment{personal}{%
\section{Personal data}%
\ifthenelse{\boolean{titleft}}{\vspace{-\mystery}}{}%
\begin{tabular}[t]{@{\bfseries}ll}%
}%
{\end{tabular}\par}

%-----------------------------------------------------------------------
%
\ifthenelse{\boolean{PofP}}%
{}%         .aux files (needed for the "lastpage" label)
{\nofiles}% No .aux files

%-----------------------------------------------------------------------
%
% Load the hyperref and bookmark packages last, since they redefine many
% things. We need bookmark to handle arbitrary level values.
\ifthenelse{\boolean{nohyperref}}{}%
{\RequirePackage{hyperref}\RequirePackage{bookmark}%
}

\endinput
